@@ -9,72 +9,73 @@ cumtrapz <- function(x,y){
 	return(z)
 }
 
-trapzs <- function(x,y){
-	M = length(y)
-	out = sum(diff(x)*(y[-M]+y[-1])/2)
-	return(out)
-}
-
 trapz <- function(x,y){
 	M = nrow(y)
-	N = ncol(y)
-	out = rep(0,N)
-	for (i in 1:N){
-		out[i] = sum(diff(x)*(y[-M,i]+y[-1,i])/2)
+	if (is.null(M)){
+		M = length(y)
+		out = sum(diff(x)*(y[-M]+y[-1])/2)
+	}else{
+		M = nrow(y)
+		N = ncol(y)
+		out = rep(0,N)
+		for (i in 1:N){
+			out[i] = sum(diff(x)*(y[-M,i]+y[-1,i])/2)
+		}
 	}
 	return(out)
 }
 
 simpson <- function(x,y){
 	M = nrow(y)
-	N = ncol(y)
-	
-	# use  trapz if M < 3
-	if (M < 3){
-		out = trapz(x,y)
-	}else{
-		out = rep(0,N)
-		dx = diff(x)
-		dx1 = dx[1:(length(dx)-1)]
-		dx2 = dx[2:length(dx)]
-		alpha = (dx1+dx2)/dx1/6
-		a0 = alpha*(2*dx1-dx2)
-		a1 = alpha*(dx1+dx2)^2/dx2
-		a2 = alpha*dx1/dx2*(2*dx2-dx1)
-		for (i in 1:N){
-			require("matrixcalc")
-			out[i] = sum(a0[seq(1,length(a0),2)]*y[seq(1,M-2,2),i] + a1[seq(1,length(a1),2)]*y[seq(2,M-1,2),i]+a2[seq(1,length(a2),2)]*y[seq(3,M,2),i])
+	if (is.null(M)){
+		M = length(y)
+		if (M < 3){
+			out = trapz(x,y)
+		}else{
+			dx = diff(x)
+			dx1 = dx[1:(length(dx)-1)]
+			dx2 = dx[2:length(dx)]
+			alpha = (dx1+dx2)/dx1/6
+			a0 = alpha*(2*dx1-dx2)
+			a1 = alpha*(dx1+dx2)^2/dx2
+			a2 = alpha*dx1/dx2*(2*dx2-dx1)
+			
+			out = sum(a0[seq(1,length(a0),2)]*y[seq(1,M-2,2)] + a1[seq(1,length(a1),2)]*y[seq(2,M-1,2)]+a2[seq(1,length(a2),2)]*y[seq(3,M,2)])
 			if (M %% 2 == 0){
+				require("matrixcalc")
 				A = vandermonde.matrix(x[(length(x)-2):length(x)],3)
 				C = solve(A[,3:1],y[(length(y)-2):length(y)])
-				out[i] = out[i] + C[1]*(x[length(x)]^3-x[(length(x)-1)]^3)/3 + C[2]*(x[length(x)]^3-x[(length(x)-1)]^2)/2 + C[3]*dx[length(dx)]
+				out = out + C[1]*(x[length(x)]^3-x[(length(x)-1)]^3)/3 + C[2]*(x[length(x)]^2-x[(length(x)-1)]^2)/2 + C[3]*dx[length(dx)]
+			}
+		}
+	}else{
+		M = nrow(y)
+		N = ncol(y)
+		
+		# use  trapz if M < 3
+		if (M < 3){
+			out = trapz(x,y)
+		}else{
+			out = rep(0,N)
+			dx = diff(x)
+			dx1 = dx[1:(length(dx)-1)]
+			dx2 = dx[2:length(dx)]
+			alpha = (dx1+dx2)/dx1/6
+			a0 = alpha*(2*dx1-dx2)
+			a1 = alpha*(dx1+dx2)^2/dx2
+			a2 = alpha*dx1/dx2*(2*dx2-dx1)
+			for (i in 1:N){
+				require("matrixcalc")
+				out[i] = sum(a0[seq(1,length(a0),2)]*y[seq(1,M-2,2),i] + a1[seq(1,length(a1),2)]*y[seq(2,M-1,2),i]+a2[seq(1,length(a2),2)]*y[seq(3,M,2),i])
+				if (M %% 2 == 0){
+					A = vandermonde.matrix(x[(length(x)-2):length(x)],3)
+					C = solve(A[,3:1],y[(length(y)-2):length(y)])
+					out[i] = out[i] + C[1]*(x[length(x)]^3-x[(length(x)-1)]^3)/3 + C[2]*(x[length(x)]^3-x[(length(x)-1)]^2)/2 + C[3]*dx[length(dx)]
+				}
 			}
 		}
 	}
-	return(out)
-}
-
-simpson_s <- function(x,y){
-	M = length(y)
-	if (M < 3){
-		out = trapz(x,y)
-	}else{
-		dx = diff(x)
-		dx1 = dx[1:(length(dx)-1)]
-		dx2 = dx[2:length(dx)]
-		alpha = (dx1+dx2)/dx1/6
-		a0 = alpha*(2*dx1-dx2)
-		a1 = alpha*(dx1+dx2)^2/dx2
-		a2 = alpha*dx1/dx2*(2*dx2-dx1)
-		
-		out = sum(a0[seq(1,length(a0),2)]*y[seq(1,M-2,2)] + a1[seq(1,length(a1),2)]*y[seq(2,M-1,2)]+a2[seq(1,length(a2),2)]*y[seq(3,M,2)])
-		if (M %% 2 == 0){
-			require("matrixcalc")
-			A = vandermonde.matrix(x[(length(x)-2):length(x)],3)
-			C = solve(A[,3:1],y[(length(y)-2):length(y)])
-			out = out + C[1]*(x[length(x)]^3-x[(length(x)-1)]^3)/3 + C[2]*(x[length(x)]^2-x[(length(x)-1)]^2)/2 + C[3]*dx[length(dx)]
-		}
-	}
+	
 	return(out)
 }
 
